/*
** Module   : EmptySet.java
** Abstract : implementation of an empty set
**
** Copyright (c) 2006-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------------------Description-----------------------------
** 001 ECF 20061112   @31131 Created initial version. Implementation of an
**                           empty set.
** 002 GES 20090421   @41822 Moved to a more generic package.
** 003 ECF 20131013          Implemented generics.
*/

package com.goldencode.util;

import java.util.*;

/**
 * Implementation of a (reasonably) low overhead, empty set.  This is
 * essentially a do-nothing object to be used when a safe implementation of
 * the <code>Set</code> interface is required for an API, but the set must be
 * empty.  It overrides the minimum <code>AbstractSet</code> methods
 * necessary to function as a read-only, empty set.  Elements may not be
 * added.
 */
public final class EmptySet<E>
extends AbstractSet<E>
{
   /** Empty iterator which is stateless, so it is safe to share */
   private final Iterator<E> emptyIter = new EmptyIterator<E>();
   
   /**
    * Return an iterator that never has a next element, and which does not
    * support element removal.
    *
    * @return  No-op iterator.
    */
   public Iterator<E> iterator()
   {
      return emptyIter;
   }
   
   /**
    * Return a size of zero, to indicate the set is empty.
    *
    * @return  Zero.
    */
   public int size()
   {
      return 0;
   }
}
